@@ -35,17 +35,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 {-|
 Module      : Data.Default
-Description : Defines a class for types with a default value.
+Description : A class for types with a default value.
 
 This module defines a class for types with a default value. Instances are
-provided for '()', 'Data.Set.Set', 'Data.Map.Map', 'Int', 'Integer',
+provided for @()@, 'Data.Set.Set', 'Data.Map.Map', 'Int', 'Integer',
 'Float', 'Double', and many others (see below).
 -}
 module Data.Default (
     Default(..)
 ) where
 
-import Data.Default.Class
-import Data.Default.Instances.Containers ()
-import Data.Default.Instances.DList      ()
-import Data.Default.Instances.OldLocale  ()
+import Data.Default.Internal
